# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileProfileResultValue(Model):
    """Encapsulates information about a profile results value (measurement or
    timepoint).

    All required parameters must be populated in order to send to Azure.

    :param item_id: Required. The id of the item in the profile.
    :type item_id: int
    :param data_value: The computed data value for the given item
    :type data_value: float
    """

    _validation = {
        'item_id': {'required': True},
    }

    _attribute_map = {
        'item_id': {'key': 'itemId', 'type': 'int'},
        'data_value': {'key': 'dataValue', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileProfileResultValue, self).__init__(**kwargs)
        self.item_id = kwargs.get('item_id', None)
        self.data_value = kwargs.get('data_value', None)
