# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadParameters(Model):
    """Passed back to the client when a multi-part upload is started. This
    contains further
    instructions on how to proceed with the upload, including the transfer ID
    to pass to
    future calls, as well as any change of URL for the actual chunk uploads.

    :param transfer_id: The ID of the transfer; this will be used when making
     subsequent calls to the upload APIs
    :type transfer_id: str
    :param url: The URL for the transfer; data block transfers regarding this
     upload should go to this URL.
     This may also be an empty string, in which case you should keep using the
     normal URLs
    :type url: str
    """

    _attribute_map = {
        'transfer_id': {'key': 'transferId', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
    }

    def __init__(self, *, transfer_id: str=None, url: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoUploadUploadParameters, self).__init__(**kwargs)
        self.transfer_id = transfer_id
        self.url = url
