# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoMetadata(Model):
    """Encapsulates metadata information for a parameter or analytic in EMS.

    :param values: The metadata for the object.
    :type values: list[~emsapi.models.AdiEmsWebApiV2DtoMetadataItem]
    """

    _attribute_map = {
        'values': {'key': 'values', 'type': '[AdiEmsWebApiV2DtoMetadataItem]'},
    }

    def __init__(self, *, values=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoMetadata, self).__init__(**kwargs)
        self.values = values
