# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileResultComment(Model):
    """Encapsulates information about a comment.

    All required parameters must be populated in order to send to Azure.

    :param user: Required. The user associated with the comment
    :type user: str
    :param date_property: Required. The date and time the comment was added
     (UTC)
    :type date_property: datetime
    :param comment: Required. The text of the comment
    :type comment: str
    """

    _validation = {
        'user': {'required': True},
        'date_property': {'required': True},
        'comment': {'required': True},
    }

    _attribute_map = {
        'user': {'key': 'user', 'type': 'str'},
        'date_property': {'key': 'date', 'type': 'iso-8601'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoProfileProfileResultComment, self).__init__(**kwargs)
        self.user = kwargs.get('user', None)
        self.date_property = kwargs.get('date_property', None)
        self.comment = kwargs.get('comment', None)
