# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoTrajectoryConfiguration(Model):
    """Encapsulates a data point defining the userOptions config for a Google
    Earth export.

    :param trajectory_id: A unique identifier for this type of KML trajectory.
     Typically this just the name of the file sans extension.
    :type trajectory_id: str
    :param description: A description of what kind of trajectory this KML type
     generates.
    :type description: str
    """

    _attribute_map = {
        'trajectory_id': {'key': 'trajectoryId', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoTrajectoryConfiguration, self).__init__(**kwargs)
        self.trajectory_id = kwargs.get('trajectory_id', None)
        self.description = kwargs.get('description', None)
