# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiCoreDtoDataRange(Model):
    """AdiEmsWebApiCoreDtoDataRange.

    :param min:
    :type min: float
    :param max:
    :type max: float
    """

    _attribute_map = {
        'min': {'key': 'min', 'type': 'float'},
        'max': {'key': 'max', 'type': 'float'},
    }

    def __init__(self, *, min: float=None, max: float=None, **kwargs) -> None:
        super(AdiEmsWebApiCoreDtoDataRange, self).__init__(**kwargs)
        self.min = min
        self.max = max
