# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQueryResult(Model):
    """Represents the tabular results of a data source query.

    All required parameters must be populated in order to send to Azure.

    :param header: Required. An ordered list of header column information,
     describing the fields included in the results and matching
     the order of columns in the resulting data rows
    :type header:
     list[~emsapi.models.AdiEmsWebApiV2DtoSchemaQueryResultHeader]
    :param rows: Required. An array of arrays representing the resulting data
     rows of a query. Each inner array represents a single
     results row
    :type rows: list[list[object]]
    :param is_partial_result: Required. Indicates whether the rows returned
     are a partial query result because the maximum amount of rows that can
     be returned has been reached.
    :type is_partial_result: bool
    """

    _validation = {
        'header': {'required': True},
        'rows': {'required': True},
        'is_partial_result': {'required': True},
    }

    _attribute_map = {
        'header': {'key': 'header', 'type': '[AdiEmsWebApiV2DtoSchemaQueryResultHeader]'},
        'rows': {'key': 'rows', 'type': '[[object]]'},
        'is_partial_result': {'key': 'isPartialResult', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaQueryResult, self).__init__(**kwargs)
        self.header = kwargs.get('header', None)
        self.rows = kwargs.get('rows', None)
        self.is_partial_result = kwargs.get('is_partial_result', None)
