# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaAsyncQueryInfo(Model):
    """Passed back to the client when an async query is started. This contains
    query header
    information, and a unique ID, with which the user can later read data for
    this query.

    :param id: The ID of the query; this will be used when making subsequent
     calls to the query APIs.
    :type id: str
    :param inactivity_timeout: The number of seconds of inactivity after which
     an async query is eligible for automatic deletion.
    :type inactivity_timeout: int
    :param header: An ordered list of header column information, describing
     the fields included in the results and matching
     the order of columns in the resulting data rows.
    :type header:
     list[~emsapi.models.AdiEmsWebApiV2DtoSchemaQueryResultHeader]
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'inactivity_timeout': {'key': 'inactivityTimeout', 'type': 'int'},
        'header': {'key': 'header', 'type': '[AdiEmsWebApiV2DtoSchemaQueryResultHeader]'},
    }

    def __init__(self, *, id: str=None, inactivity_timeout: int=None, header=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaAsyncQueryInfo, self).__init__(**kwargs)
        self.id = id
        self.inactivity_timeout = inactivity_timeout
        self.header = header
