# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaDatabase(Model):
    """Represents a database type exposed by an EMS installation.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier for the database
    :type id: str
    :param plural_name: Required. A plural display name for the database
    :type plural_name: str
    :param singular_name: Required. A singular display name for the database
    :type singular_name: str
    """

    _validation = {
        'id': {'required': True},
        'plural_name': {'required': True},
        'singular_name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'plural_name': {'key': 'pluralName', 'type': 'str'},
        'singular_name': {'key': 'singularName', 'type': 'str'},
    }

    def __init__(self, *, id: str, plural_name: str, singular_name: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaDatabase, self).__init__(**kwargs)
        self.id = id
        self.plural_name = plural_name
        self.singular_name = singular_name
