# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQueryResultHeader(Model):
    """Represents a header column in data source query result.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier of the field associated
     with this column
    :type id: str
    :param name: Required. The user-friendly display name of the field
     associated with this column
    :type name: str
    :param units: The units of values of the field associated with this
     column. This value may be empty if not applicable
    :type units: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'units': {'key': 'units', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaQueryResultHeader, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.units = kwargs.get('units', None)
