# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAssetFlightPhase(Model):
    """A flight phase is a coarse division of a flight into sections, such as
    takeoff, climb and enroute.
    The flight phases are used as inputs into some analytics.

    :param id: The identifier of the flight phase within the system.
    :type id: int
    :param description: The description for this phase of flight.
    :type description: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoAssetFlightPhase, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.description = kwargs.get('description', None)
