# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestViews(Model):
    """AdiEmsWebSharedTableauRestViews.

    :param view:
    :type view: list[~emsapi.models.AdiEmsWebSharedTableauRestView]
    """

    _attribute_map = {
        'view': {'key': 'view', 'type': '[AdiEmsWebSharedTableauRestView]'},
    }

    def __init__(self, *, view=None, **kwargs) -> None:
        super(AdiEmsWebSharedTableauRestViews, self).__init__(**kwargs)
        self.view = view
