# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary(Model):
    """AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary.

    :param glossary_version: The version of the EMS glossary the results were
     generated from.
    :type glossary_version: int
    :param profile_id: The local identifier of the profile
    :type profile_id: int
    :param profile_guid: The unique GUID of the profile in the system
    :type profile_guid: str
    :param current_version: The version of the associated profile
    :type current_version: int
    :param current_version_guid: The GUID identifier for the version of this
     profile.
    :type current_version_guid: str
    :param glossary_items: Array of entries in this glossary.
    :type glossary_items:
     list[~emsapi.models.AdiEmsWebApiV2DtoEmsProfileGlossaryItem]
    """

    _attribute_map = {
        'glossary_version': {'key': 'glossaryVersion', 'type': 'int'},
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_guid': {'key': 'profileGuid', 'type': 'str'},
        'current_version': {'key': 'currentVersion', 'type': 'int'},
        'current_version_guid': {'key': 'currentVersionGuid', 'type': 'str'},
        'glossary_items': {'key': 'glossaryItems', 'type': '[AdiEmsWebApiV2DtoEmsProfileGlossaryItem]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary, self).__init__(**kwargs)
        self.glossary_version = kwargs.get('glossary_version', None)
        self.profile_id = kwargs.get('profile_id', None)
        self.profile_guid = kwargs.get('profile_guid', None)
        self.current_version = kwargs.get('current_version', None)
        self.current_version_guid = kwargs.get('current_version_guid', None)
        self.glossary_items = kwargs.get('glossary_items', None)
