# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticAnalyticId(Model):
    """Provides an identifier for an individual analytic.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier of the analytic.
    :type id: str
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
    }

    def __init__(self, *, id: str, **kwargs) -> None:
        super(AdiEmsWebApiV2ModelAnalyticAnalyticId, self).__init__(**kwargs)
        self.id = id
