# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaField(Model):
    """Represents an individual field that can be accessed within a data source.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier for the field
    :type id: str
    :param type: Required. The data type of the underlying data stored for the
     field. Possible values include: 'boolean', 'dateTime', 'discrete',
     'number', 'string'
    :type type: str or ~emsapi.models.enum
    :param name: Required. The display name for the field
    :type name: str
    """

    _validation = {
        'id': {'required': True},
        'type': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, *, id: str, type, name: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaField, self).__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name
