# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiModelError(Model):
    """AdiEmsWebApiModelError.

    All required parameters must be populated in order to send to Azure.

    :param message: Required.
    :type message: str
    :param message_detail: Required.
    :type message_detail: str
    :param unexpected: Required.
    :type unexpected: bool
    """

    _validation = {
        'message': {'required': True},
        'message_detail': {'required': True},
        'unexpected': {'required': True},
    }

    _attribute_map = {
        'message': {'key': 'message', 'type': 'str'},
        'message_detail': {'key': 'messageDetail', 'type': 'str'},
        'unexpected': {'key': 'unexpected', 'type': 'bool'},
    }

    def __init__(self, *, message: str, message_detail: str, unexpected: bool, **kwargs) -> None:
        super(AdiEmsWebApiModelError, self).__init__(**kwargs)
        self.message = message
        self.message_detail = message_detail
        self.unexpected = unexpected
