# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAnalyticGroupContents(Model):
    """Represents the contents of an analytic group.

    :param groups: An in-order listing of the groups contained in the
     specified group
    :type groups: list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticGroup]
    :param analytics: An in-order listing of the analytics contained in the
     specified group
    :type analytics: list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticInfo]
    """

    _attribute_map = {
        'groups': {'key': 'groups', 'type': '[AdiEmsWebApiV2DtoAnalyticGroup]'},
        'analytics': {'key': 'analytics', 'type': '[AdiEmsWebApiV2DtoAnalyticInfo]'},
    }

    def __init__(self, *, groups=None, analytics=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoAnalyticGroupContents, self).__init__(**kwargs)
        self.groups = groups
        self.analytics = analytics
