# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus(Model):
    """A single flight result within a larger download result.

    :param flight_record: The flight record for the flight
    :type flight_record: int
    :param flight_status: A description of the flight record's processing
     state. This should be checked before assuming
     that the flight is correct and complete. Possible values include:
     'notProcessed', 'processed', 'failure'
    :type flight_status: str or ~emsapi.models.enum
    """

    _attribute_map = {
        'flight_record': {'key': 'flightRecord', 'type': 'int'},
        'flight_status': {'key': 'flightStatus', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus, self).__init__(**kwargs)
        self.flight_record = kwargs.get('flight_record', None)
        self.flight_status = kwargs.get('flight_status', None)
