# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestSite(Model):
    """AdiEmsWebSharedTableauRestSite.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param content_url:
    :type content_url: str
    :param admin_mode:
    :type admin_mode: str
    :param user_quota:
    :type user_quota: str
    :param storage_quota:
    :type storage_quota: str
    :param state:
    :type state: str
    :param status_reason:
    :type status_reason: str
    :param revision_history_enabled:
    :type revision_history_enabled: bool
    :param subscribe_others_enabled:
    :type subscribe_others_enabled: bool
    :param revision_limit:
    :type revision_limit: int
    :param guest_access_enabled:
    :type guest_access_enabled: bool
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'content_url': {'key': 'contentUrl', 'type': 'str'},
        'admin_mode': {'key': 'adminMode', 'type': 'str'},
        'user_quota': {'key': 'userQuota', 'type': 'str'},
        'storage_quota': {'key': 'storageQuota', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'status_reason': {'key': 'statusReason', 'type': 'str'},
        'revision_history_enabled': {'key': 'revisionHistoryEnabled', 'type': 'bool'},
        'subscribe_others_enabled': {'key': 'subscribeOthersEnabled', 'type': 'bool'},
        'revision_limit': {'key': 'revisionLimit', 'type': 'int'},
        'guest_access_enabled': {'key': 'guestAccessEnabled', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebSharedTableauRestSite, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.content_url = kwargs.get('content_url', None)
        self.admin_mode = kwargs.get('admin_mode', None)
        self.user_quota = kwargs.get('user_quota', None)
        self.storage_quota = kwargs.get('storage_quota', None)
        self.state = kwargs.get('state', None)
        self.status_reason = kwargs.get('status_reason', None)
        self.revision_history_enabled = kwargs.get('revision_history_enabled', None)
        self.subscribe_others_enabled = kwargs.get('subscribe_others_enabled', None)
        self.revision_limit = kwargs.get('revision_limit', None)
        self.guest_access_enabled = kwargs.get('guest_access_enabled', None)
