# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoTrajectoryValue(Model):
    """Encapsulates a data point defining the positional information
    [lat/long/alt]
    for a sample and the location it occurred at, in seconds from start of
    file.

    :param offset: The offset of the value, in seconds from start of file.
    :type offset: float
    :param latitude: The latitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type latitude: float
    :param longitude: The longitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type longitude: float
    :param altitude: The altitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type altitude: float
    """

    _attribute_map = {
        'offset': {'key': 'offset', 'type': 'float'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'altitude': {'key': 'altitude', 'type': 'float'},
    }

    def __init__(self, *, offset: float=None, latitude: float=None, longitude: float=None, altitude: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoTrajectoryValue, self).__init__(**kwargs)
        self.offset = offset
        self.latitude = latitude
        self.longitude = longitude
        self.altitude = altitude
