# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestUser(Model):
    """AdiEmsWebSharedTableauRestUser.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param site_role:
    :type site_role: str
    :param last_login:
    :type last_login: datetime
    :param external_auth_user_id:
    :type external_auth_user_id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'site_role': {'key': 'siteRole', 'type': 'str'},
        'last_login': {'key': 'lastLogin', 'type': 'iso-8601'},
        'external_auth_user_id': {'key': 'externalAuthUserId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebSharedTableauRestUser, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.site_role = kwargs.get('site_role', None)
        self.last_login = kwargs.get('last_login', None)
        self.external_auth_user_id = kwargs.get('external_auth_user_id', None)
