# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid(Model):
    """A single navaid associated with a procedure segment.

    :param navaid_id: The ID of the navaid referenced by this segment.
    :type navaid_id: int
    :param bearing: The bearing to the navaid.
    :type bearing: float
    :param distance: The distance to the navaid.
    :type distance: float
    """

    _attribute_map = {
        'navaid_id': {'key': 'navaidId', 'type': 'int'},
        'bearing': {'key': 'bearing', 'type': 'float'},
        'distance': {'key': 'distance', 'type': 'float'},
    }

    def __init__(self, *, navaid_id: int=None, bearing: float=None, distance: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid, self).__init__(**kwargs)
        self.navaid_id = navaid_id
        self.bearing = bearing
        self.distance = distance
