# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoParameterSetParameterSet(Model):
    """Encapsulates the some data defining a ParameterSet.

    :param name: The name of the ParameterSet.
    :type name: str
    :param description: An optional description of the ParameterSet.
    :type description: str
    :param items: An array of the parameters contained in the ParameterSet.
    :type items:
     list[~emsapi.models.AdiEmsWebApiV2DtoParameterSetParameterSetItem]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'items': {'key': 'items', 'type': '[AdiEmsWebApiV2DtoParameterSetParameterSetItem]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoParameterSetParameterSet, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.items = kwargs.get('items', None)
