# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaGroupByColumn(Model):
    """Represents a column of data that can be used in a group-by clause of a data
    source query.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. The unique string identifier of the field to
     use in a group-by clause of a query
    :type field_id: str
    """

    _validation = {
        'field_id': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'str'},
    }

    def __init__(self, *, field_id: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaGroupByColumn, self).__init__(**kwargs)
        self.field_id = field_id
