# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationAirport(Model):
    """Information about a single airport.

    :param id: The unique identifier for this airport.
    :type id: int
    :param name: The name of the airport.
    :type name: str
    :param ata_code: The ATA (FAA) code is the US-specific 3-letter identifier
     (e.g. ORD)
    :type ata_code: str
    :param city: The city of the airport.
    :type city: str
    :param country: The country of the airport.
    :type country: str
    :param ems_code: The airport code as it should be displayed by EMS apps.
    :type ems_code: str
    :param icao_code: The ICAO code is the international 4-letter identifier
     (e.g. KORD).
    :type icao_code: str
    :param latitude: The latitude of the airport.
    :type latitude: float
    :param longitude: The longitude of the airport.
    :type longitude: float
    :param altitude: The altitude of the airport
    :type altitude: float
    :param magnetic_variation: The magnetic variation of the airport.
    :type magnetic_variation: float
    :param type: The type of airport (e.g. civil, military)
    :type type: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'ata_code': {'key': 'ataCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'ems_code': {'key': 'emsCode', 'type': 'str'},
        'icao_code': {'key': 'icaoCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'altitude': {'key': 'altitude', 'type': 'float'},
        'magnetic_variation': {'key': 'magneticVariation', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, name: str=None, ata_code: str=None, city: str=None, country: str=None, ems_code: str=None, icao_code: str=None, latitude: float=None, longitude: float=None, altitude: float=None, magnetic_variation: float=None, type: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationAirport, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.ata_code = ata_code
        self.city = city
        self.country = country
        self.ems_code = ems_code
        self.icao_code = icao_code
        self.latitude = latitude
        self.longitude = longitude
        self.altitude = altitude
        self.magnetic_variation = magnetic_variation
        self.type = type
