# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherWeatherReport(Model):
    """Represents TAF and METAR weather reports collected by an EMS system.

    All required parameters must be populated in order to send to Azure.

    :param taf_reports: Required. A list of collected TAF reports from an EMS
     system
    :type taf_reports:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTafReport]
    :param metar_reports: Required. A list of collected METAR reports from an
     EMS system
    :type metar_reports:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarMetarReport]
    """

    _validation = {
        'taf_reports': {'required': True},
        'metar_reports': {'required': True},
    }

    _attribute_map = {
        'taf_reports': {'key': 'tafReports', 'type': '[AdiEmsWebApiV2DtoWeatherTafTafReport]'},
        'metar_reports': {'key': 'metarReports', 'type': '[AdiEmsWebApiV2DtoWeatherMetarMetarReport]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherWeatherReport, self).__init__(**kwargs)
        self.taf_reports = kwargs.get('taf_reports', None)
        self.metar_reports = kwargs.get('metar_reports', None)
